pub struct Node<Solution> {
pub id: usize,
pub solution: Solution,
pub score: f32,
}Expand description
A node is a wrapper that contains one specific solution for an experiment that was created during a genetic run.
Fields
id: usizesolution: Solutionscore: f32Trait Implementations
impl<Solution: Copy> Copy for Node<Solution>